# encoding: utf-8
#-----------------------------------------------------------
# Copyright (C) 2016 Martin Dobias
#-----------------------------------------------------------
# Licensed under the terms of GNU GPL 2
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#---------------------------------------------------------------------

import os
from PyQt4 import uic

from PyQt4.QtGui import *

from sql_generator import SqlGenerator

this_dir = os.path.dirname(__file__)

WIDGET, BASE = uic.loadUiType(os.path.join(this_dir, 'trigger_delete_dialog.ui'))

class TriggerDeleteDialog(BASE, WIDGET):
    def __init__(self, conn, invalid_triggers, parent=None):
        BASE.__init__(self, parent)
        self.setupUi(self)
        self.conn = conn    # psycopg2 connection to the DB
        self.invalid_triggers = invalid_triggers
        self.model = QStandardItemModel()
        self.triggerList.setModel(self.model)

        self.buttonBox.accepted.connect(self.on_ok)

        self.show_invalid_triggers()

    def show_invalid_triggers(self):
        self.model.clear()
        self.model.setHorizontalHeaderLabels(["ID", "Source Table", "Target Table"])
        index = -1
        for trigger_id, src, trg in self.invalid_triggers:
            index += 1
            item_0 = QStandardItem(str(trigger_id))
            item_0.setData(index)  # store index of the item in self.triggers (used in _current_item_to_generator)
            item_1 = QStandardItem(src)
            item_2 = QStandardItem(trg)
            for i in [item_0, item_1, item_2]:
                i.setEditable(False)
            self.model.appendRow([item_0, item_1, item_2])
        self.triggerList.resizeColumnToContents(1)


    def on_ok(self):
        """ Do some sanity checks before accepting the dialog """
        for trigger_id, src, trg in self.invalid_triggers:
            sql_gen = SqlGenerator()
            sql_gen.trg_fcn_id = trigger_id
            sql_gen.source_table = src
            sql_gen.target_table = trg
            sql = sql_gen.drop_sql()

            cur = self.conn.cursor()
            cur.execute("BEGIN;" + sql + "COMMIT;")
        self.accept()
